@@ -87,10 +87,10 @@ typedef struct intCharTupple {
 /**
  * Mapping between braille dot and textual representation as used in dots operands
  */
-const static intCharTupple dotMapping[] = {
+static const intCharTupple dotMapping[] = {
 	{ B1, '1' }, { B2, '2' }, { B3, '3' }, { B4, '4' }, { B5, '5' }, { B6, '6' },
 	{ B7, '7' }, { B8, '8' }, { B9, '9' }, { B10, 'A' }, { B11, 'B' }, { B12, 'C' },
-	{ B13, 'D' }, { B14, 'E' }, { B15, 'F' }, 0,
+	{ B13, 'D' }, { B14, 'E' }, { B15, 'F' }, { 0, 0 },
 };
 
 /* HASHNUM must be prime */
@@ -549,15 +549,15 @@ typedef enum {
 	alloc_typebuf,
 	alloc_wordBuffer,
 	alloc_emphasisBuffer,
-	alloc_transNoteBuffer,
 	alloc_destSpacing,
-	alloc_passbuf1,
-	alloc_passbuf2,
+	alloc_passbuf,
 	alloc_posMapping1,
 	alloc_posMapping2,
 	alloc_posMapping3
 } AllocBuf;
 
+#define MAXPASSBUF 3
+
 typedef enum {
 	capsRule = 0,
 	emph1Rule = 1,
@@ -584,6 +584,20 @@ typedef enum {
 	lenPhraseOffset = 8
 } EmphCodeOffset;
 
+/* Grouping the begin, end, word and symbol bits and using the type of
+ * a single bit group for representing the emphasis classes allows us
+ * to do simple bit operations. */
+
+typedef struct {
+	unsigned int begin : 16;
+	unsigned int end : 16;
+	unsigned int word : 16;
+	unsigned int symbol : 16;
+} EmphasisInfo;
+
+/* An emphasis class is a bit field that contains a single "1" */
+typedef unsigned int EmphasisClass;
+
 typedef enum { noEncoding, bigEndian, littleEndian, ascii8 } EncodingType;
 
 typedef struct {
@@ -645,7 +659,7 @@ _lou_getCharFromDots(widechar d);
  * TODO: move to utils.c
  */
 void *EXPORT_CALL
-_lou_allocMem(AllocBuf buffer, int srcmax, int destmax);
+_lou_allocMem(AllocBuf buffer, int index, int srcmax, int destmax);
 
 /**
  * Hash function for character strings
