@@ -70,7 +70,7 @@ try:
 except NameError:
     # Unix/Cygwin
     _loader = cdll
-liblouis = _loader["liblouis.so.7.1"]
+liblouis = _loader["liblouis.so.7.2"]
 
 atexit.register(liblouis.lou_free)
 
@@ -348,8 +348,6 @@ no_contract = 0x1000
 noContractions = 1
 compbrlAtCursor = 2
 dotsIO = 4
-comp8Dots = 8
-pass1Only = 16
 compbrlLeftCursor = 32
 ucBrl = 64
 noUndefinedDots = 128
